import RDSDataService from 'aws-sdk/clients/rdsdataservice';
declare type Coercer = (value: {
    intValue: number;
    stringValue: string;
    bigIntValue: number;
    longValue: number;
    booleanValue: boolean;
} & {
    [key: string]: any;
}) => number | string | boolean;
declare type EscapeFunction = (source: string) => string;
declare type FullJitter = (retries: number) => number;
export declare type AdapterPool = {
    config?: {
        dbClusterOrInstanceArn: string;
        awsSecretStoreArn: string;
        databaseName: string;
        eventsTableName: string;
        secretsTableName: string;
        snapshotsTableName: string;
        region?: string;
        snapshotBucketSize?: number;
    };
    rdsDataService?: typeof RDSDataService;
    dbClusterOrInstanceArn?: string;
    awsSecretStoreArn?: string;
    databaseName?: string;
    eventsTableName?: string;
    secretsTableName?: string;
    snapshotsTableName?: string;
    fullJitter?: FullJitter;
    coercer?: Coercer;
    executeStatement?: (sql: string) => Promise<any[] | null>;
    escapeId?: EscapeFunction;
    escape?: EscapeFunction;
    bucketSize?: number;
};
export declare type AdapterSpecific = {
    RDSDataService: typeof RDSDataService;
    fullJitter: FullJitter;
    escapeId: EscapeFunction;
    escape: EscapeFunction;
    executeStatement: (pool: AdapterPool, sql: string) => Promise<any[] | null>;
    coercer: Coercer;
};
export declare type CloudResource = {
    createResource: (options: CloudResourceOptions) => Promise<any>;
    disposeResource: (options: CloudResourceOptions) => Promise<any>;
    destroyResource: (options: CloudResourceOptions) => Promise<any>;
};
export declare type CloudResourcePool = {
    executeStatement: (pool: AdapterPool, sql: string) => Promise<any[] | null>;
    RDSDataService: typeof RDSDataService;
    escapeId: EscapeFunction;
    escape: EscapeFunction;
    fullJitter: FullJitter;
    coercer: Coercer;
    shapeEvent: (data: any) => any;
    connect: (pool: AdapterPool, specific: AdapterSpecific) => Promise<any>;
    dispose: (pool: AdapterPool) => Promise<any>;
};
export declare type CloudResourceOptions = {
    region: string;
    databaseName: string;
    eventsTableName: string;
    secretsTableName: string;
    snapshotsTableName: string;
    userLogin: string;
    awsSecretStoreArn: string;
    awsSecretStoreAdminArn: string;
    dbClusterOrInstanceArn: string;
};
export {};
